@@ -3,12 +3,14 @@
 """
 
 from .util.marshal import *
+from .util.pm_assert import pm_assert
 from .util.type import *
 
 
 __all__ = [
     'InitArgsError',
     'marshal_csv',
+    'pm_assert',
     'type_assert',
     'type_assert_iter',
     'unmarshal_csv',
@@ -54,7 +56,9 @@ def unmarshal_csv(
 
     Args:
         iterable: list-or-tuple-of-objects
-        cls:      type-or-function, The type to unmarshal into
+        cls:
+            type-or-function or {"row header": function},
+            The type to unmarshal into
     Returns:
         List of instances of @cls
     Raises:
@@ -64,3 +68,4 @@ def unmarshal_csv(
         unmarshal_list(x, cls)
         for x in iterable
     ]
+
